==> 0.8.2.tar.gz: lib/widget/vgk-card-image-with-copy-widget/vgk-card-image-with-copy-widget.dart <==
import 'dart:async';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:clipboard/clipboard.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-image-with-copy-widget-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkCardImageWithCopyWidget extends StatefulWidget {
  const VgkCardImageWithCopyWidget(
      {Key key,
      this.mainScreenAnimationController,
      this.mainScreenAnimation,
      this.data})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final VgkCardImageWithCopyWidgetModel data;
  @override
  _VgkCardImageWithCopyWidgetState createState() =>
      _VgkCardImageWithCopyWidgetState();
}

class _VgkCardImageWithCopyWidgetState extends State<VgkCardImageWithCopyWidget>
    with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform:
                VgkProGamingTheme.subTransform(widget.mainScreenAnimation),
            child: Container(
              child: Card(
                child: Container(
                  child: Column(
                    children: [
                      Padding(
                        padding: EdgeInsets.fromLTRB(12, 0, 12, 0),
                        child: Row(
                          children: <Widget>[
                            Padding(
                              padding: EdgeInsets.fromLTRB(0, 12, 0, 12),
                              child: Text(
                                widget.data.key,
                                textAlign: TextAlign.left,
                                style: VgkProGamingTheme.h1,
                              ),
                            ),
                            Spacer(),
                            new ButtonBar(
                              children: <Widget>[
                                Visibility(
                                  visible: (widget.data.bgmi == null ||
                                          widget.data.bgmi == "")
                                      ? false
                                      : true,
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: <Widget>[
                                      new IconButton(
                                        icon: Icon(
                                          Icons.copy,
                                          color: VgkProGamingTheme.primaryColor,
                                        ),
                                        onPressed: () {
                                          FlutterClipboard.copy(
                                              widget.data.bgmi);
                                        },
                                      ),
                                      Text("Bgmi"),
                                    ],
                                  ),
                                ),
                                Visibility(
                                  visible: (widget.data.global == null ||
                                          widget.data.global == "")
                                      ? false
                                      : true,
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: <Widget>[
                                      new IconButton(
                                        icon: Icon(
                                          Icons.copy,
                                          color: VgkProGamingTheme.primaryColor,
                                        ),
                                        onPressed: () {
                                          FlutterClipboard.copy(
                                            widget.data.global,
                                          );
                                        },
                                      ),
                                      Text("global"),
                                    ],
                                  ),
                                )
                              ],
                            )
                          ],
                        ),
                      ),
                      AspectRatio(
                        aspectRatio: 2,
                        child: CachedNetworkImage(
                          imageUrl: widget.data.src,
                          fit: BoxFit.fill,
                          progressIndicatorBuilder:
                              (context, url, downloadProgress) =>
                                  CircularProgressIndicator(
                                      value: downloadProgress.progress),
                          errorWidget: (context, url, error) =>
                              Icon(Icons.error),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
              decoration: new BoxDecoration(
                boxShadow: [
                  new BoxShadow(
                    color: Colors.grey.shade500,
                    blurRadius: 20.0,
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}

==> 0.8.4.tar.gz: lib/widget/vgk-card-image-with-copy-widget/vgk-card-image-with-copy-widget.dart <==
import 'dart:async';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:clipboard/clipboard.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-image-with-copy-widget-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkCardImageWithCopyWidget extends StatefulWidget {
  const VgkCardImageWithCopyWidget(
      {Key key,
      this.mainScreenAnimationController,
      this.mainScreenAnimation,
      this.data})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final VgkCardImageWithCopyWidgetModel data;
  @override
  _VgkCardImageWithCopyWidgetState createState() =>
      _VgkCardImageWithCopyWidgetState();
}

class _VgkCardImageWithCopyWidgetState extends State<VgkCardImageWithCopyWidget>
    with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform:
                VgkProGamingTheme.subTransform(widget.mainScreenAnimation),
            child: Container(
              child: Card(
                child: Container(
                  child: Column(
                    children: [
                      Padding(
                        padding: EdgeInsets.fromLTRB(12, 0, 12, 0),
                        child: Row(
                          children: <Widget>[
                            Padding(
                              padding: EdgeInsets.fromLTRB(0, 12, 0, 12),
                              child: Text(
                                widget.data.key,
                                textAlign: TextAlign.left,
                                style: VgkProGamingTheme.h1,
                              ),
                            ),
                            Spacer(),
                            new ButtonBar(
                              children: <Widget>[
                                Visibility(
                                  visible: (widget.data.bgmi == null ||
                                          widget.data.bgmi == "")
                                      ? false
                                      : true,
                                  child: InkWell(
                                    onTap: () {
                                      FlutterClipboard.copy(widget.data.bgmi);
                                      final snackBar = SnackBar(
                                        content: const Text(
                                            "BGMI Share Code Copied"),
                                      );
                                      ScaffoldMessenger.of(context)
                                          .showSnackBar(snackBar);
                                    },
                                    child: Row(
                                      mainAxisSize: MainAxisSize.min,
                                      children: <Widget>[
                                        new IconButton(
                                          icon: Icon(
                                            Icons.copy,
                                            size: 10,
                                            color:
                                                VgkProGamingTheme.primaryColor,
                                          ),
                                        ),
                                        Text("bgmi code"),
                                      ],
                                    ),
                                  ),
                                ),
                                Visibility(
                                  visible: (widget.data.global == null ||
                                          widget.data.global == "")
                                      ? false
                                      : true,
                                  child: InkWell(
                                    onTap: () {
                                      FlutterClipboard.copy(
                                        widget.data.global,
                                      );
                                      final snackBar = SnackBar(
                                        content: const Text(
                                            "Global Share Code Copied"),
                                      );
                                      ScaffoldMessenger.of(context)
                                          .showSnackBar(snackBar);
                                    },
                                    child: Row(
                                      mainAxisSize: MainAxisSize.min,
                                      children: <Widget>[
                                        new IconButton(
                                          icon: Icon(
                                            Icons.copy,
                                            size: 10,
                                            color:
                                                VgkProGamingTheme.primaryColor,
                                          ),
                                        ),
                                        Text("global code"),
                                      ],
                                    ),
                                  ),
                                )
                              ],
                            )
                          ],
                        ),
                      ),
                      AspectRatio(
                        aspectRatio: 2,
                        child: CachedNetworkImage(
                          imageUrl: widget.data.src,
                          fit: BoxFit.fill,
                          progressIndicatorBuilder:
                              (context, url, downloadProgress) =>
                                  CircularProgressIndicator(
                                      value: downloadProgress.progress),
                          errorWidget: (context, url, error) =>
                              Icon(Icons.error),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
              decoration: new BoxDecoration(
                boxShadow: [
                  new BoxShadow(
                    color: Colors.grey.shade500,
                    blurRadius: 20.0,
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
